declare class MemoryCache {
    /**
     * set item to local storage
     *
     * @example
     * memoryCache.set('key1', 'key1-value');
     * memoryCache.set('key1', 10);
     * memoryCache.set('key1', { id: 1, name: 'name 1'});
     * memoryCache.set('key1', 'key1-value', false);
     * @param key string
     * @param value string | number | object
     */
    set<TValue = string>(key: string, value: TValue): void;
    /**
     * get item from local storage
     *
     * @example
     * memoryCache.get('key1');
     * memoryCache.get<number>('key1');
     * memoryCache.get<User>('key1');
     * memoryCache.get<User[]>('key1');
     *
     * @param key string
     * @param compress compress data default true
     */
    get<TValue = string>(key: string): TValue;
    /**
     * remove key from storage
     * @param key cache key
     */
    remove(key: string): void;
    /**
     * has cache
     * @param key cache key
     */
    has(key: string): boolean;
    /**
     * clear all storage
     */
    clear(): void;
    /**
     * add item to list
     * @example
     * memoryCache.add(`key`, `001`, `value 001`);
     * memoryCache.add(`key`, `001`, { name: 'name 001' });
     * memoryCache.add(`key`, `001`, `value 001`, max);
     */
    listAdd<TValue = string>(key: string, id: string, value: TValue, max?: number): void;
    /**
     * get item from list
     * @example
     * memoryCache.get(`key`, `001`);
     */
    listGet<TValue>(key: string, id: string): TValue;
    size(): number;
}
declare const memoryCache: MemoryCache;
export { memoryCache };
//# sourceMappingURL=memory-cache.d.ts.map