declare const cache: {
    /**
     * set item to local storage
     *
     * @example
     * cache.set('key1', 'key1-value');
     * cache.set('key1', 10);
     * cache.set('key1', { id: 1, name: 'name 1'});
     * cache.set('key1', 'key1-value', false);
     * @param key string
     * @param value string | number | object
     * @param compress compress data default true
     */
    set<TValue = string>(key: string, value: TValue): void;
    /**
     * get item from local storage
     *
     * @example
     * cache.get('key1');
     * cache.get<number>('key1');
     * cache.get<User>('key1');
     * cache.get<User[]>('key1');
     * cache.get('key1', false);
     *
     * @param key string
     */
    get<TValue = string>(key: string): TValue | undefined;
    /**
     * remove key from storage
     * @param key cache key
     */
    remove(key: string): void;
    /**
     * clear all storage
     */
    clear(): void;
};
export { cache };
//# sourceMappingURL=storage-cache.d.ts.map